@@ -23,7 +23,7 @@
 
 class CrossfeedPreset : public PluginPresetBase {
  public:
-  CrossfeedPreset(PresetType preset_type, const int& index = 0);
+  explicit CrossfeedPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
