@@ -23,7 +23,7 @@
 
 class CrystalizerPreset : public PluginPresetBase {
  public:
-  CrystalizerPreset(PresetType preset_type, const int& index = 0);
+  explicit CrystalizerPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
