@@ -23,7 +23,7 @@
 
 class DeesserPreset : public PluginPresetBase {
  public:
-  DeesserPreset(PresetType preset_type, const int& index = 0);
+  explicit DeesserPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
