@@ -48,15 +48,15 @@ class Equalizer : public PluginBase {
 
   auto get_latency_seconds() -> float override;
 
-  float latency_port_value = 0.0F;
+  void sort_bands();
+
+  static constexpr uint max_bands = 32U;
 
  private:
   GSettings *settings_left = nullptr, *settings_right = nullptr;
 
   std::unique_ptr<lv2::Lv2Wrapper> lv2_wrapper;
 
-  static constexpr uint max_bands = 32U;
-
   uint latency_n_frames = 0U;
 
   std::vector<gulong> gconnections_unified;
