@@ -35,7 +35,7 @@ class MultibandCompressor : public PluginBase {
   auto operator=(const MultibandCompressor&&) -> MultibandCompressor& = delete;
   ~MultibandCompressor() override;
 
-  static constexpr uint n_bands = 8U;
+  static constexpr uint n_bands = tags::multiband_compressor::n_bands;
 
   void setup() override;
 
@@ -52,8 +52,6 @@ class MultibandCompressor : public PluginBase {
 
   sigc::signal<void(const std::array<float, n_bands>)> reduction, envelope, curve, frequency_range;
 
-  float latency_port_value = 0.0F;
-
   std::array<float, n_bands> frequency_range_end_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
   std::array<float, n_bands> envelope_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
   std::array<float, n_bands> curve_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
@@ -110,7 +108,7 @@ class MultibandCompressor : public PluginBase {
 
     gconnections.push_back(g_signal_connect(settings, ("changed::"s + band_external_sidechain[n].data()).c_str(),
                                             G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                                              auto self = static_cast<MultibandCompressor*>(user_data);
+                                              auto* self = static_cast<MultibandCompressor*>(user_data);
 
                                               self->update_sidechain_links(key);
                                             }),
