@@ -35,7 +35,7 @@ class MultibandGate : public PluginBase {
   auto operator=(const MultibandGate&&) -> MultibandGate& = delete;
   ~MultibandGate() override;
 
-  static constexpr uint n_bands = 8U;
+  static constexpr uint n_bands = tags::multiband_gate::n_bands;
 
   void setup() override;
 
@@ -109,7 +109,7 @@ class MultibandGate : public PluginBase {
 
     gconnections.push_back(g_signal_connect(settings, ("changed::"s + band_external_sidechain[n].data()).c_str(),
                                             G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                                              auto self = static_cast<MultibandGate*>(user_data);
+                                              auto* self = static_cast<MultibandGate*>(user_data);
 
                                               self->update_sidechain_links(key);
                                             }),
