@@ -67,6 +67,10 @@ class PluginBase {
 
   pw_filter* filter = nullptr;
 
+  pw_filter_state state = PW_FILTER_STATE_UNCONNECTED;
+
+  bool can_get_node_id = false;
+
   bool enable_probe = false;
 
   uint n_samples = 0U;
@@ -85,6 +89,8 @@ class PluginBase {
 
   float notification_time_window = 1.0F / 20.0F;  // seconds
 
+  float latency_value = 0.0F;  // seconds
+
   std::chrono::time_point<std::chrono::system_clock> clock_start;
 
   std::vector<float> dummy_left, dummy_right;
@@ -156,6 +162,8 @@ class PluginBase {
 
   static void apply_gain(std::span<float>& left, std::span<float>& right, const float& gain);
 
+  void update_filter_params();
+
  private:
   uint node_id = 0U;
 
