@@ -23,6 +23,10 @@
 
 namespace tags::multiband_gate {
 
+// mb gate band num const
+
+constexpr unsigned n_bands = 8U;
+
 // gsettings keys tags
 
 constexpr auto band_enable = std::to_array({{"enable-band0"},
