@@ -73,6 +73,11 @@ void append_to_string_list(GtkStringList* string_list, const std::string& name);
 
 void remove_from_string_list(GtkStringList* string_list, const std::string& name);
 
+void gsettings_bind_enum_to_dropdown(GSettings* settings,
+                                     const gchar* key,
+                                     GtkDropDown* dropdown,
+                                     GSettingsBindFlags flags = G_SETTINGS_BIND_DEFAULT);
+
 template <StringLiteralWrapper sl_wrapper, bool lower_bound = true>
 void prepare_spinbutton(GtkSpinButton* button) {
   if (button == nullptr) {
