@@ -25,6 +25,7 @@ namespace app {
 
 using namespace std::string_literals;
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(Application, application, ADW_TYPE_APPLICATION)
 
 void hide_all_windows(GApplication* app) {
@@ -155,7 +156,7 @@ void on_startup(GApplication* gapp) {
 
   self->data->gconnections_soe.push_back(g_signal_connect(
       self->soe_settings, "changed::output-device", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-        auto self = static_cast<Application*>(user_data);
+        auto* self = static_cast<Application*>(user_data);
 
         const auto name = util::gsettings_get_string(settings, key);
 
@@ -175,7 +176,7 @@ void on_startup(GApplication* gapp) {
 
   self->data->gconnections_sie.push_back(g_signal_connect(
       self->sie_settings, "changed::input-device", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-        auto self = static_cast<Application*>(user_data);
+        auto* self = static_cast<Application*>(user_data);
 
         const auto name = util::gsettings_get_string(settings, key);
 
@@ -195,7 +196,7 @@ void on_startup(GApplication* gapp) {
 
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::bypass", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-        auto self = static_cast<Application*>(user_data);
+        auto* self = static_cast<Application*>(user_data);
 
         update_bypass_state(self);
       }),
@@ -412,8 +413,13 @@ void application_init(Application* self) {
 
   entries[1] = {"help",
                 [](GSimpleAction* action, GVariant* parameter, gpointer gapp) {
-                  gtk_show_uri(gtk_application_get_active_window(GTK_APPLICATION(gapp)), "help:easyeffects",
-                               GDK_CURRENT_TIME);
+                  auto* parent = gtk_application_get_active_window(GTK_APPLICATION(gapp));
+
+                  auto* launcher = gtk_uri_launcher_new("help:easyeffects");
+
+                  gtk_uri_launcher_launch(launcher, parent, nullptr, nullptr, nullptr);
+
+                  g_object_unref(launcher);
                 },
                 nullptr, nullptr, nullptr};
 
