@@ -52,6 +52,7 @@ struct _AppsBox {
   Data* data;
 };
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(AppsBox, apps_box, GTK_TYPE_BOX)
 
 auto app_is_blocklisted(AppsBox* self, const std::string& name) -> bool {
@@ -61,11 +62,8 @@ auto app_is_blocklisted(AppsBox* self, const std::string& name) -> bool {
 }
 
 void update_empty_list_overlay(AppsBox* self) {
-  if (g_list_model_get_n_items(G_LIST_MODEL(self->apps_model)) == 0) {
-    gtk_widget_show(GTK_WIDGET(self->overlay_empty_list));
-  } else {
-    gtk_widget_hide(GTK_WIDGET(self->overlay_empty_list));
-  }
+  gtk_widget_set_visible(GTK_WIDGET(self->overlay_empty_list),
+                         (g_list_model_get_n_items(G_LIST_MODEL(self->apps_model)) == 0) ? 1 : 0);
 }
 
 void on_app_added(AppsBox* self, const NodeInfo& node_info) {
@@ -95,8 +93,8 @@ void on_app_added(AppsBox* self, const NodeInfo& node_info) {
 
   /*
     As g_list_store_append calls increases the object reference count we remove the one added by g_object_new in the
-    object creation. The reference added by g_list_store_append will be removed by an additional call to g_object_unref
-    after g_list_store_remove is called
+    object creation. The reference added by g_list_store_append will be removed by an additional call to
+    g_object_unref after g_list_store_remove is called
   */
 
   g_object_unref(holder);
