@@ -39,7 +39,7 @@ Compressor::Compressor(const std::string& tag,
 
   gconnections.push_back(g_signal_connect(settings, "changed::sidechain-type",
                                           G_CALLBACK(+[](GSettings* settings, const char* key, gpointer user_data) {
-                                            auto self = static_cast<Compressor*>(user_data);
+                                            auto* self = static_cast<Compressor*>(user_data);
 
                                             self->update_sidechain_links(key);
                                           }),
@@ -47,7 +47,7 @@ Compressor::Compressor(const std::string& tag,
 
   gconnections.push_back(g_signal_connect(settings, "changed::sidechain-input-device",
                                           G_CALLBACK(+[](GSettings* settings, const char* key, gpointer user_data) {
-                                            auto self = static_cast<Compressor*>(user_data);
+                                            auto* self = static_cast<Compressor*>(user_data);
 
                                             self->update_sidechain_links(key);
                                           }),
@@ -156,9 +156,9 @@ void Compressor::process(std::span<float>& left_in,
   if (latency_n_frames != lv) {
     latency_n_frames = lv;
 
-    latency_port_value = static_cast<float>(latency_n_frames) / static_cast<float>(rate);
+    latency_value = static_cast<float>(latency_n_frames) / static_cast<float>(rate);
 
-    util::debug(log_tag + name + " latency: " + util::to_string(latency_port_value, "") + " s");
+    util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
     util::idle_add([=, this]() {
       if (!post_messages || latency.empty()) {
@@ -168,19 +168,7 @@ void Compressor::process(std::span<float>& left_in,
       latency.emit();
     });
 
-    spa_process_latency_info latency_info{};
-
-    latency_info.ns = static_cast<uint64_t>(latency_port_value * 1000000000.0F);
-
-    std::array<char, 1024U> buffer{};
-
-    spa_pod_builder b{};
-
-    spa_pod_builder_init(&b, buffer.data(), sizeof(buffer));
-
-    const spa_pod* param = spa_process_latency_build(&b, SPA_PARAM_ProcessLatency, &latency_info);
-
-    pw_filter_update_params(filter, nullptr, &param, 1);
+    update_filter_params();
   }
 
   if (post_messages) {
@@ -237,5 +225,5 @@ void Compressor::update_probe_links() {
 }
 
 auto Compressor::get_latency_seconds() -> float {
-  return this->latency_port_value;
+  return this->latency_value;
 }
