@@ -34,7 +34,7 @@ EchoCanceller::EchoCanceller(const std::string& tag,
       near_end_suppression(g_settings_get_int(settings, "near-end-suppression")) {
   gconnections.push_back(g_signal_connect(settings, "changed::filter-length",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                                            auto self = static_cast<EchoCanceller*>(user_data);
+                                            auto* self = static_cast<EchoCanceller*>(user_data);
 
                                             std::scoped_lock<std::mutex> lock(self->data_mutex);
 
@@ -186,19 +186,7 @@ void EchoCanceller::process(std::span<float>& left_in,
       latency.emit();
     });
 
-    spa_process_latency_info latency_info{};
-
-    latency_info.ns = static_cast<uint64_t>(latency_value * 1000000000.0F);
-
-    std::array<char, 1024U> buffer{};
-
-    spa_pod_builder b{};
-
-    spa_pod_builder_init(&b, buffer.data(), sizeof(buffer));
-
-    const spa_pod* param = spa_process_latency_build(&b, SPA_PARAM_ProcessLatency, &latency_info);
-
-    pw_filter_update_params(filter, nullptr, &param, 1);
+    update_filter_params();
 
     notify_latency = false;
   }
