@@ -52,7 +52,7 @@ Equalizer::Equalizer(const std::string& tag,
 
   gconnections.push_back(g_signal_connect(settings, "changed::num-bands",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                                            auto self = static_cast<Equalizer*>(user_data);
+                                            auto* self = static_cast<Equalizer*>(user_data);
 
                                             const uint nbands = g_settings_get_int(settings, key);
 
@@ -233,9 +233,9 @@ void Equalizer::process(std::span<float>& left_in,
   if (latency_n_frames != lv) {
     latency_n_frames = lv;
 
-    latency_port_value = static_cast<float>(latency_n_frames) / static_cast<float>(rate);
+    latency_value = static_cast<float>(latency_n_frames) / static_cast<float>(rate);
 
-    util::debug(log_tag + name + " latency: " + util::to_string(latency_port_value, "") + " s");
+    util::debug(log_tag + name + " latency: " + util::to_string(latency_value, "") + " s");
 
     util::idle_add([=, this]() {
       if (!post_messages || latency.empty()) {
@@ -245,19 +245,7 @@ void Equalizer::process(std::span<float>& left_in,
       latency.emit();
     });
 
-    spa_process_latency_info latency_info{};
-
-    latency_info.ns = static_cast<uint64_t>(latency_port_value * 1000000000.0F);
-
-    std::array<char, 1024U> buffer{};
-
-    spa_pod_builder b{};
-
-    spa_pod_builder_init(&b, buffer.data(), sizeof(buffer));
-
-    const spa_pod* param = spa_process_latency_build(&b, SPA_PARAM_ProcessLatency, &latency_info);
-
-    pw_filter_update_params(filter, nullptr, &param, 1);
+    update_filter_params();
   }
 
   if (post_messages) {
@@ -269,6 +257,61 @@ void Equalizer::process(std::span<float>& left_in,
   }
 }
 
+void Equalizer::sort_bands() {
+  struct EQ_Band {
+    gdouble freq;
+    gint type;
+    gint mode;
+    gint slope;
+    gdouble gain;
+    gdouble q;
+    gboolean solo;
+    gboolean mute;
+  };
+
+  const auto used_bands = static_cast<uint>(g_settings_get_int(settings, "num-bands"));
+  if (used_bands < 1U || used_bands > max_bands) {
+    return;
+  }
+
+  std::vector<GSettings*> settings_channels{settings_left};
+  if (g_settings_get_boolean(settings, "split-channels") != 0) {
+    settings_channels.push_back(settings_right);
+  }
+
+  using namespace tags::equalizer;
+
+  for (auto* channel : settings_channels) {
+    std::multimap<gdouble, struct EQ_Band> sorted_bands;
+
+    for (uint n = 0U; n < used_bands; n++) {
+      const auto f = g_settings_get_double(channel, band_frequency[n].data());
+
+      sorted_bands.emplace(
+          std::pair<double, struct EQ_Band>(f, {.freq = f,
+                                                .type = g_settings_get_enum(channel, band_type[n].data()),
+                                                .mode = g_settings_get_enum(channel, band_mode[n].data()),
+                                                .slope = g_settings_get_enum(channel, band_slope[n].data()),
+                                                .gain = g_settings_get_double(channel, band_gain[n].data()),
+                                                .q = g_settings_get_double(channel, band_q[n].data()),
+                                                .solo = g_settings_get_boolean(channel, band_solo[n].data()),
+                                                .mute = g_settings_get_boolean(channel, band_mute[n].data())}));
+    }
+
+    for (uint n = 0U; const auto& p : sorted_bands) {
+      g_settings_set_double(channel, band_frequency[n].data(), p.second.freq);
+      g_settings_set_enum(channel, band_type[n].data(), p.second.type);
+      g_settings_set_enum(channel, band_mode[n].data(), p.second.mode);
+      g_settings_set_enum(channel, band_slope[n].data(), p.second.slope);
+      g_settings_set_double(channel, band_gain[n].data(), p.second.gain);
+      g_settings_set_double(channel, band_q[n].data(), p.second.q);
+      g_settings_set_boolean(channel, band_solo[n].data(), p.second.solo);
+      g_settings_set_boolean(channel, band_mute[n].data(), p.second.mute);
+      n++;
+    }
+  }
+}
+
 auto Equalizer::get_latency_seconds() -> float {
-  return latency_port_value;
+  return latency_value;
 }
