@@ -23,8 +23,6 @@ namespace ui::equalizer_box {
 
 using namespace tags::equalizer;
 
-constexpr uint max_bands = 32U;
-
 enum Channel { left, right };
 
 struct APO_Band {
@@ -77,7 +75,7 @@ struct _EqualizerBox {
 
   GtkSpinButton *nbands, *balance, *pitch_left, *pitch_right;
 
-  GtkComboBoxText* mode;
+  GtkDropDown* mode;
 
   GtkToggleButton* split_channels;
 
@@ -88,6 +86,7 @@ struct _EqualizerBox {
   Data* data;
 };
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(EqualizerBox, equalizer_box, GTK_TYPE_BOX)
 
 void on_reset(EqualizerBox* self, GtkButton* btn) {
@@ -97,6 +96,7 @@ void on_reset(EqualizerBox* self, GtkButton* btn) {
 }
 
 void on_flat_response(EqualizerBox* self, GtkButton* btn) {
+  const auto& max_bands = self->data->equalizer->max_bands;
   for (uint n = 0U; n < max_bands; n++) {
     g_settings_reset(self->settings_left, band_gain[n].data());
 
@@ -315,7 +315,10 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
     return false;
   }
 
-  std::ranges::stable_sort(bands, {}, &APO_Band::freq);
+  /* Sort bands by freq is made by user through Equalizer::sort_bands()
+  std::ranges::stable_sort(bands, {}, &APO_Band::freq); */
+
+  const auto& max_bands = self->data->equalizer->max_bands;
 
   // Apply APO parameters obtained
   g_settings_set_int(self->settings, "num-bands",
@@ -362,41 +365,50 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
 void on_import_apo_preset_clicked(EqualizerBox* self, GtkButton* btn) {
   auto* active_window = gtk_application_get_active_window(GTK_APPLICATION(self->data->application));
 
-  auto* dialog = gtk_file_chooser_native_new(_("Import APO Preset File"), active_window, GTK_FILE_CHOOSER_ACTION_OPEN,
-                                             _("Open"), _("Cancel"));
+  auto* dialog = gtk_file_dialog_new();
+
+  gtk_file_dialog_set_title(dialog, _("Import APO Preset File"));
+  gtk_file_dialog_set_accept_label(dialog, _("Open"));
+
+  GListStore* filters = g_list_store_new(GTK_TYPE_FILE_FILTER);
 
   auto* filter = gtk_file_filter_new();
 
   gtk_file_filter_add_pattern(filter, "*.txt");
   gtk_file_filter_set_name(filter, _("APO Presets"));
 
-  gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
+  g_list_store_append(filters, filter);
 
-  g_signal_connect(dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
-                     if (response != GTK_RESPONSE_ACCEPT) {
-                       g_object_unref(dialog);
-                       return;
-                     }
+  g_object_unref(filter);
 
-                     auto* chooser = GTK_FILE_CHOOSER(dialog);
-                     auto* file = gtk_file_chooser_get_file(chooser);
-                     auto* path = g_file_get_path(file);
+  gtk_file_dialog_set_filters(dialog, G_LIST_MODEL(filters));
 
-                     if (!import_apo_preset(self, path)) {
-                       // notify error on preset loading
-                       ui::show_fixed_toast(
-                           self->toast_overlay,
-                           _("APO Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
-                     }
+  g_object_unref(filters);
 
-                     g_free(path);
-                     g_object_unref(file);
-                     g_object_unref(dialog);
-                   }),
-                   self);
+  gtk_file_dialog_open(
+      dialog, active_window, nullptr,
+      +[](GObject* source_object, GAsyncResult* result, gpointer user_data) {
+        auto* self = static_cast<EqualizerBox*>(user_data);
+        auto* dialog = GTK_FILE_DIALOG(source_object);
 
-  gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(dialog), 1);
-  gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
+        auto* file = gtk_file_dialog_open_finish(dialog, result, nullptr);
+
+        if (file != nullptr) {
+          auto* path = g_file_get_path(file);
+
+          if (!import_apo_preset(self, path)) {
+            // notify error on preset loading
+            ui::show_fixed_toast(
+                self->toast_overlay,
+                _("APO Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
+          }
+
+          g_free(path);
+
+          g_object_unref(file);
+        }
+      },
+      self);
 }
 
 // ### End APO Preset Section ###
@@ -509,7 +521,10 @@ auto import_graphiceq_preset(EqualizerBox* self, const std::string& file_path) -
     return false;
   }
 
-  std::ranges::stable_sort(bands, {}, &GraphicEQ_Band::freq);
+  /* Sort bands by freq is made by user through Equalizer::sort_bands()
+  std::ranges::stable_sort(bands, {}, &GraphicEQ_Band::freq); */
+
+  const auto& max_bands = self->data->equalizer->max_bands;
 
   // Apply GraphicEQ parameters obtained
   g_settings_set_int(self->settings, "num-bands",
@@ -553,47 +568,55 @@ auto import_graphiceq_preset(EqualizerBox* self, const std::string& file_path) -
 void on_import_geq_preset_clicked(EqualizerBox* self, GtkButton* btn) {
   auto* active_window = gtk_application_get_active_window(GTK_APPLICATION(self->data->application));
 
-  auto* dialog = gtk_file_chooser_native_new(_("Import GraphicEQ Preset File"), active_window,
-                                             GTK_FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
+  auto* dialog = gtk_file_dialog_new();
+
+  gtk_file_dialog_set_title(dialog, _("Import GraphicEQ Preset File"));
+  gtk_file_dialog_set_accept_label(dialog, _("Open"));
+
+  GListStore* filters = g_list_store_new(GTK_TYPE_FILE_FILTER);
 
   auto* filter = gtk_file_filter_new();
 
   gtk_file_filter_add_pattern(filter, "*.txt");
   gtk_file_filter_set_name(filter, _("GraphicEQ Presets"));
 
-  gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
+  g_list_store_append(filters, filter);
 
-  g_signal_connect(
-      dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
-        if (response != GTK_RESPONSE_ACCEPT) {
-          g_object_unref(dialog);
-          return;
+  g_object_unref(filter);
+
+  gtk_file_dialog_set_filters(dialog, G_LIST_MODEL(filters));
+
+  g_object_unref(filters);
+
+  gtk_file_dialog_open(
+      dialog, active_window, nullptr,
+      +[](GObject* source_object, GAsyncResult* result, gpointer user_data) {
+        auto* self = static_cast<EqualizerBox*>(user_data);
+        auto* dialog = GTK_FILE_DIALOG(source_object);
+
+        auto* file = gtk_file_dialog_open_finish(dialog, result, nullptr);
+
+        if (file != nullptr) {
+          auto* path = g_file_get_path(file);
+
+          if (!import_graphiceq_preset(self, path)) {
+            // notify error on preset loading
+            ui::show_fixed_toast(
+                self->toast_overlay,
+                _("GraphicEQ Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
+          }
+
+          g_free(path);
+
+          g_object_unref(file);
         }
-
-        auto* chooser = GTK_FILE_CHOOSER(dialog);
-        auto* file = gtk_file_chooser_get_file(chooser);
-        auto* path = g_file_get_path(file);
-
-        if (!import_graphiceq_preset(self, path)) {
-          // notify error on preset loading
-          ui::show_fixed_toast(
-              self->toast_overlay,
-              _("GraphicEQ Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
-        }
-
-        g_free(path);
-        g_object_unref(file);
-        g_object_unref(dialog);
-      }),
+      },
       self);
-
-  gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(dialog), 1);
-  gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
 }
 
 // ### End GraphicEQ Section ###
 
-auto sort_bands(EqualizerBox* self, const int nbands, GSettings* settings, const bool& sort_by_freq)
+auto sort_band_widgets(EqualizerBox* self, const int nbands, GSettings* settings, const bool& sort_by_freq)
     -> std::vector<std::string> {
   std::vector<int> list(nbands);
 
@@ -620,18 +643,18 @@ auto sort_bands(EqualizerBox* self, const int nbands, GSettings* settings, const
   return output;
 }
 
-void build_all_bands(EqualizerBox* self, const bool& sort_by_freq) {
+void build_all_bands(EqualizerBox* self, const bool& sort_by_freq = false) {
   const auto split = g_settings_get_boolean(self->settings, "split-channels") != 0;
 
   const auto nbands = g_settings_get_int(self->settings, "num-bands");
 
-  auto list = sort_bands(self, nbands, self->settings_left, sort_by_freq);
+  auto list = sort_band_widgets(self, nbands, self->settings_left, sort_by_freq);
 
   gtk_string_list_splice(self->string_list_left, 0, g_list_model_get_n_items(G_LIST_MODEL(self->string_list_left)),
                          util::make_gchar_pointer_vector(list).data());
 
   if (split) {
-    list = sort_bands(self, nbands, self->settings_right, sort_by_freq);
+    list = sort_band_widgets(self, nbands, self->settings_right, sort_by_freq);
 
     gtk_string_list_splice(self->string_list_right, 0, g_list_model_get_n_items(G_LIST_MODEL(self->string_list_right)),
                            util::make_gchar_pointer_vector(list).data());
@@ -639,7 +662,7 @@ void build_all_bands(EqualizerBox* self, const bool& sort_by_freq) {
 }
 
 void on_sort_bands(EqualizerBox* self, GtkButton* btn) {
-  build_all_bands(self, true);
+  self->data->equalizer->sort_bands();
 }
 
 template <Channel channel>
@@ -719,7 +742,7 @@ void setup(EqualizerBox* self,
   setup_listview<Channel::left>(self);
   setup_listview<Channel::right>(self);
 
-  build_all_bands(self, false);
+  build_all_bands(self);
 
   self->data->connections.push_back(equalizer->input_level.connect([=](const float left, const float right) {
     util::idle_add([=]() {
@@ -750,7 +773,7 @@ void setup(EqualizerBox* self,
 
   g_settings_bind(self->settings, "split-channels", self->split_channels, "active", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "mode", self->mode, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_dropdown(self->settings, "mode", self->mode);
 
   g_settings_bind(self->settings, "balance", gtk_spin_button_get_adjustment(self->balance), "value",
                   G_SETTINGS_BIND_DEFAULT);
@@ -763,13 +786,13 @@ void setup(EqualizerBox* self,
 
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::num-bands",
-      G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) { build_all_bands(self, false); }), self));
+      G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) { build_all_bands(self); }), self));
 
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::split-channels", G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) {
         gtk_stack_set_visible_child_name(self->stack, "page_left_channel");
 
-        build_all_bands(self, false);
+        build_all_bands(self);
       }),
       self));
 }
