@@ -23,8 +23,6 @@ namespace ui::multiband_compressor_box {
 
 using namespace std::string_literals;
 
-constexpr uint n_bands = 8U;
-
 struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
@@ -54,7 +52,7 @@ struct _MultibandCompressorBox {
 
   GtkSpinButton *dry, *wet;
 
-  GtkComboBoxText *compressor_mode, *envelope_boost;
+  GtkDropDown *compressor_mode, *envelope_boost;
 
   GtkDropDown* dropdown_input_devices;
 
@@ -62,11 +60,12 @@ struct _MultibandCompressorBox {
 
   GSettings* settings;
 
-  std::array<ui::multiband_compressor_band_box::MultibandCompressorBandBox*, n_bands> bands;
+  std::array<ui::multiband_compressor_band_box::MultibandCompressorBandBox*, tags::multiband_compressor::n_bands> bands;
 
   Data* data;
 };
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(MultibandCompressorBox, multiband_compressor_box, GTK_TYPE_BOX)
 
 void on_reset(MultibandCompressorBox* self, GtkButton* btn) {
@@ -82,7 +81,7 @@ void on_listbox_row_selected(MultibandCompressorBox* self, GtkListBoxRow* row, G
 }
 
 void set_dropdown_input_devices_sensitivity(MultibandCompressorBox* self) {
-  for (uint n = 0U; n < n_bands; n++) {
+  for (uint n = 0U; n < tags::multiband_compressor::n_bands; n++) {
     if (g_settings_get_boolean(self->settings, tags::multiband_compressor::band_external_sidechain[n].data()) != 0) {
       gtk_widget_set_sensitive(GTK_WIDGET(self->dropdown_input_devices), 1);
 
@@ -94,7 +93,7 @@ void set_dropdown_input_devices_sensitivity(MultibandCompressorBox* self) {
 }
 
 void create_bands(MultibandCompressorBox* self) {
-  for (uint n = 0; n < n_bands; n++) {
+  for (uint n = 0; n < tags::multiband_compressor::n_bands; n++) {
     auto* band_box = ui::multiband_compressor_band_box::create();
 
     ui::multiband_compressor_band_box::setup(band_box, self->settings, n);
@@ -193,8 +192,8 @@ void setup(MultibandCompressorBox* self,
         });
       }));
 
-  self->data->connections.push_back(
-      multiband_compressor->frequency_range.connect([=](const std::array<float, n_bands> values) {
+  self->data->connections.push_back(multiband_compressor->frequency_range.connect(
+      [=](const std::array<float, tags::multiband_compressor::n_bands> values) {
         util::idle_add([=]() {
           if (get_ignore_filter_idle_add(serial)) {
             return;
@@ -207,7 +206,7 @@ void setup(MultibandCompressorBox* self,
       }));
 
   self->data->connections.push_back(
-      multiband_compressor->envelope.connect([=](const std::array<float, n_bands> values) {
+      multiband_compressor->envelope.connect([=](const std::array<float, tags::multiband_compressor::n_bands> values) {
         util::idle_add([=]() {
           if (get_ignore_filter_idle_add(serial)) {
             return;
@@ -219,20 +218,21 @@ void setup(MultibandCompressorBox* self,
         });
       }));
 
-  self->data->connections.push_back(multiband_compressor->curve.connect([=](const std::array<float, n_bands> values) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
+  self->data->connections.push_back(
+      multiband_compressor->curve.connect([=](const std::array<float, tags::multiband_compressor::n_bands> values) {
+        util::idle_add([=]() {
+          if (get_ignore_filter_idle_add(serial)) {
+            return;
+          }
 
-      for (size_t n = 0U; n < values.size(); n++) {
-        ui::multiband_compressor_band_box::set_curve_label(self->bands[n], values[n]);
-      }
-    });
-  }));
+          for (size_t n = 0U; n < values.size(); n++) {
+            ui::multiband_compressor_band_box::set_curve_label(self->bands[n], values[n]);
+          }
+        });
+      }));
 
   self->data->connections.push_back(
-      multiband_compressor->reduction.connect([=](const std::array<float, n_bands> values) {
+      multiband_compressor->reduction.connect([=](const std::array<float, tags::multiband_compressor::n_bands> values) {
         util::idle_add([=]() {
           if (get_ignore_filter_idle_add(serial)) {
             return;
@@ -258,7 +258,7 @@ void setup(MultibandCompressorBox* self,
       g_object_unref(holder);
     }
 
-    auto holder = ui::holders::create(info);
+    auto* holder = ui::holders::create(info);
 
     g_list_store_append(self->input_devices_model, holder);
 
@@ -288,9 +288,9 @@ void setup(MultibandCompressorBox* self,
 
   g_settings_bind(self->settings, "wet", gtk_spin_button_get_adjustment(self->wet), "value", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "compressor-mode", self->compressor_mode, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_dropdown(self->settings, "compressor-mode", self->compressor_mode);
 
-  g_settings_bind(self->settings, "envelope-boost", self->envelope_boost, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_dropdown(self->settings, "envelope-boost", self->envelope_boost);
 
   g_settings_bind(self->settings, "enable-band1", self->enable_band1, "active", G_SETTINGS_BIND_DEFAULT);
   g_settings_bind(self->settings, "enable-band2", self->enable_band2, "active", G_SETTINGS_BIND_DEFAULT);
