@@ -83,6 +83,7 @@ auto spa_dict_get_bool(const spa_dict* props, const char* key, bool& b) -> bool
 void on_removed_proxy(void* data) {
   auto* const pd = static_cast<proxy_data*>(data);
 
+  // NOLINTNEXTLINE(clang-analyzer-core.NullDereference)
   if (pd->object_listener.link.next != nullptr || pd->object_listener.link.prev != nullptr) {
     spa_hook_remove(&pd->object_listener);
   }
@@ -1426,8 +1427,11 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
   util::debug("compiled with PipeWire: " + header_version);
   util::debug("linked to PipeWire: " + library_version);
 
+  // this needs to occur after pw_init(), so putting it before pw_init() in the initializer breaks this
+  // NOLINTNEXTLINE(cppcoreguidelines-prefer-member-initializer)
   thread_loop = pw_thread_loop_new("ee-pipewire-thread", nullptr);
 
+  // NOLINTNEXTLINE(clang-analyzer-core.NullDereference)
   if (thread_loop == nullptr) {
     util::error("could not create PipeWire loop");
   }
@@ -1785,6 +1789,14 @@ void PipeManager::sync_wait_unlock() const {
   pw_thread_loop_unlock(thread_loop);
 }
 
+auto PipeManager::wait_full() const -> int {
+  timespec abstime;
+
+  pw_thread_loop_get_time(thread_loop, &abstime, 30 * SPA_NSEC_PER_SEC);
+
+  return pw_thread_loop_timed_wait_full(thread_loop, &abstime);
+}
+
 void PipeManager::destroy_object(const int& id) const {
   lock();
 
