@@ -115,7 +115,54 @@ void on_process(void* userdata, spa_io_position* position) {
   }
 }
 
-const struct pw_filter_events filter_events = {.process = on_process};
+auto update_filter(struct spa_loop* loop, bool async, uint32_t seq, const void* data, size_t size, void* user_data)
+    -> int {
+  auto* self = static_cast<PluginBase*>(user_data);
+
+  spa_process_latency_info latency_info{};
+
+  latency_info.ns = static_cast<uint64_t>(self->latency_value * 1000000000.0F);
+
+  std::array<char, 1024U> buffer{};
+
+  spa_pod_builder b{};
+
+  spa_pod_builder_init(&b, buffer.data(), sizeof(buffer));
+
+  const spa_pod* param = spa_process_latency_build(&b, SPA_PARAM_ProcessLatency, &latency_info);
+
+  pw_filter_update_params(self->filter, nullptr, &param, 1);
+
+  return 0;
+}
+
+void on_filter_state_changed(void* userdata, pw_filter_state old, pw_filter_state state, const char* error) {
+  auto* d = static_cast<PluginBase::data*>(userdata);
+
+  d->pb->state = state;
+
+  switch (state) {
+    case PW_FILTER_STATE_ERROR:
+      d->pb->can_get_node_id = false;
+      break;
+    case PW_FILTER_STATE_UNCONNECTED:
+      d->pb->can_get_node_id = false;
+      break;
+    case PW_FILTER_STATE_CONNECTING:
+      d->pb->can_get_node_id = false;
+      break;
+    case PW_FILTER_STATE_STREAMING:
+      d->pb->can_get_node_id = true;
+      break;
+    case PW_FILTER_STATE_PAUSED:
+      d->pb->can_get_node_id = true;
+      break;
+    default:
+      break;
+  }
+}
+
+const struct pw_filter_events filter_events = {.state_changed = on_filter_state_changed, .process = on_process};
 
 }  // namespace
 
@@ -141,7 +188,7 @@ PluginBase::PluginBase(std::string tag,
 
     gconnections.push_back(g_signal_connect(settings, "changed::bypass",
                                             G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                                              auto self = static_cast<PluginBase*>(user_data);
+                                              auto* self = static_cast<PluginBase*>(user_data);
 
                                               self->bypass = g_settings_get_boolean(settings, "bypass") != 0;
                                             }),
@@ -246,12 +293,16 @@ PluginBase::PluginBase(std::string tag,
 PluginBase::~PluginBase() {
   post_messages = false;
 
+  pm->lock();
+
   if (listener.link.next != nullptr || listener.link.prev != nullptr) {
     spa_hook_remove(&listener);
   }
 
   pw_filter_destroy(filter);
 
+  pm->sync_wait_unlock();
+
   for (auto& handler_id : gconnections) {
     g_signal_handler_disconnect(settings, handler_id);
   }
@@ -271,52 +322,53 @@ void PluginBase::reset_settings() {
 
 auto PluginBase::connect_to_pw() -> bool {
   connected_to_pw = false;
-
-  /*
-    I still do not understand why we have to lock the main loop before using pw_filter_get_state after a call to
-    pw_filter_connect...
-  */
+  can_get_node_id = false;
+  state = PW_FILTER_STATE_UNCONNECTED;
 
   pm->lock();
 
-  if (pw_filter_connect(filter, PW_FILTER_FLAG_RT_PROCESS, nullptr, 0) == 0) {
-    pm->sync_wait_unlock();
+  if (pw_filter_connect(filter, PW_FILTER_FLAG_RT_PROCESS, nullptr, 0) != 0) {
+    pm->unlock();
 
-    while (pw_filter_get_state(filter, nullptr) != PW_FILTER_STATE_PAUSED) {
-      std::this_thread::sleep_for(std::chrono::milliseconds(1));
-    }
+    util::warning(log_tag + name + " cannot connect the filter to PipeWire!");
 
-    node_id = pw_filter_get_node_id(filter);
-
-    while (node_id == SPA_ID_INVALID) {
-      std::this_thread::sleep_for(std::chrono::milliseconds(1));
-
-      node_id = pw_filter_get_node_id(filter);
-    }
-
-    /*
-      The filter we link in our pipeline have at least 4 ports. Some have six. Before we try to link filters we have to
-      wait until the information about their ports is available in PipeManager's list_ports vector.
-    */
-
-    while (pm->count_node_ports(node_id) != n_ports) {
-      std::this_thread::sleep_for(std::chrono::milliseconds(1));
-    }
-
-    initialize_listener();
-
-    connected_to_pw = true;
-
-    util::debug(log_tag + name + " successfully connected to PipeWire graph");
-
-    return true;
+    return false;
   }
 
-  pm->unlock();
+  initialize_listener();
 
-  util::warning(log_tag + name + " cannot connect the filter to PipeWire!");
+  pm->sync_wait_unlock();
 
-  return false;
+  while (!can_get_node_id) {
+    std::this_thread::sleep_for(std::chrono::milliseconds(1));
+
+    if (state == PW_FILTER_STATE_ERROR) {
+      util::warning(log_tag + name + " is in an error");
+
+      return false;
+    }
+  }
+
+  pm->lock();
+
+  node_id = pw_filter_get_node_id(filter);
+
+  pm->sync_wait_unlock();
+
+  /*
+    The filter we link in our pipeline have at least 4 ports. Some have six. Before we try to link filters we have to
+    wait until the information about their ports is available in PipeManager's list_ports vector.
+  */
+
+  while (pm->count_node_ports(node_id) != n_ports) {
+    std::this_thread::sleep_for(std::chrono::milliseconds(1));
+  }
+
+  connected_to_pw = true;
+
+  util::debug(log_tag + name + " successfully connected to PipeWire graph");
+
+  return true;
 }
 
 void PluginBase::initialize_listener() {
@@ -336,6 +388,7 @@ void PluginBase::disconnect_from_pw() {
 
   set_active(false);
 
+  // NOLINTNEXTLINE(clang-analyzer-core.NullDereference)
   if (listener.link.next != nullptr || listener.link.prev != nullptr) {
     spa_hook_remove(&listener);
   }
@@ -397,7 +450,7 @@ void PluginBase::setup_input_output_gain() {
   output_gain = static_cast<float>(util::db_to_linear(g_settings_get_double(settings, "output-gain")));
 
   g_signal_connect(settings, "changed::input-gain", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                     auto self = static_cast<PluginBase*>(user_data);
+                     auto* self = static_cast<PluginBase*>(user_data);
 
                      self->input_gain = util::db_to_linear(g_settings_get_double(settings, key));
                    }),
@@ -405,7 +458,7 @@ void PluginBase::setup_input_output_gain() {
 
   g_signal_connect(settings, "changed::output-gain",
                    G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
-                     auto self = static_cast<PluginBase*>(user_data);
+                     auto* self = static_cast<PluginBase*>(user_data);
 
                      self->output_gain = util::db_to_linear(g_settings_get_double(settings, key));
                    }),
@@ -438,3 +491,7 @@ void PluginBase::notify() {
 }
 
 void PluginBase::update_probe_links() {}
+
+void PluginBase::update_filter_params() {
+  pw_loop_invoke(pw_thread_loop_get_loop(pm->thread_loop), update_filter, 1, nullptr, 0, false, this);
+}
