@@ -67,7 +67,7 @@ PresetsManager::PresetsManager()
   g_signal_connect(user_output_monitor, "changed",
                    G_CALLBACK(+[](GFileMonitor* monitor, GFile* file, GFile* other_file, GFileMonitorEvent event_type,
                                   gpointer user_data) {
-                     auto self = static_cast<PresetsManager*>(user_data);
+                     auto* self = static_cast<PresetsManager*>(user_data);
 
                      switch (event_type) {
                        case G_FILE_MONITOR_EVENT_CREATED: {
@@ -99,7 +99,7 @@ PresetsManager::PresetsManager()
   g_signal_connect(user_input_monitor, "changed",
                    G_CALLBACK(+[](GFileMonitor* monitor, GFile* file, GFile* other_file, GFileMonitorEvent event_type,
                                   gpointer user_data) {
-                     auto self = static_cast<PresetsManager*>(user_data);
+                     auto* self = static_cast<PresetsManager*>(user_data);
 
                      switch (event_type) {
                        case G_FILE_MONITOR_EVENT_CREATED: {
@@ -131,7 +131,7 @@ PresetsManager::PresetsManager()
   g_signal_connect(autoload_input_monitor, "changed",
                    G_CALLBACK(+[](GFileMonitor* monitor, GFile* file, GFile* other_file, GFileMonitorEvent event_type,
                                   gpointer user_data) {
-                     auto self = static_cast<PresetsManager*>(user_data);
+                     auto* self = static_cast<PresetsManager*>(user_data);
 
                      if (event_type == G_FILE_MONITOR_EVENT_CREATED || event_type == G_FILE_MONITOR_EVENT_DELETED) {
                        const auto profiles = self->get_autoload_profiles(PresetType::input);
@@ -150,7 +150,7 @@ PresetsManager::PresetsManager()
   g_signal_connect(autoload_output_monitor, "changed",
                    G_CALLBACK(+[](GFileMonitor* monitor, GFile* file, GFile* other_file, GFileMonitorEvent event_type,
                                   gpointer user_data) {
-                     auto self = static_cast<PresetsManager*>(user_data);
+                     auto* self = static_cast<PresetsManager*>(user_data);
 
                      if (event_type == G_FILE_MONITOR_EVENT_CREATED || event_type == G_FILE_MONITOR_EVENT_DELETED) {
                        const auto profiles = self->get_autoload_profiles(PresetType::output);
@@ -410,7 +410,9 @@ void PresetsManager::write_plugins_preset(const PresetType& preset_type,
                                           nlohmann::json& json) {
   for (const auto& name : plugins) {
     if (auto wrapper = create_wrapper(preset_type, name); wrapper != std::nullopt) {
-      wrapper.value()->write(json);
+      if (wrapper.has_value()) {
+        wrapper.value()->write(json);
+      }
     }
   }
 }
@@ -580,7 +582,9 @@ auto PresetsManager::read_plugins_preset(const PresetType& preset_type,
   for (const auto& name : plugins) {
     if (auto wrapper = create_wrapper(preset_type, name); wrapper != std::nullopt) {
       try {
-        wrapper.value()->read(json);
+        if (wrapper.has_value()) {
+          wrapper.value()->read(json);
+        }
       } catch (const nlohmann::json::exception& e) {
         notify_error(PresetError::plugin_format, name);
 
@@ -971,4 +975,4 @@ auto PresetsManager::create_wrapper(const PresetType& preset_type, std::string_v
   util::warning("The filter name " + std::string(filter_name) + " base name could not be recognized");
 
   return std::nullopt;
-}
\ No newline at end of file
+}
