@@ -43,7 +43,7 @@ struct _ReverbBox {
 
   GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
 
-  GtkComboBoxText* room_size;
+  GtkDropDown* room_size;
 
   GtkSpinButton *predelay, *decay_time, *diffusion, *dry, *wet, *hf_damp, *bass_cut, *treble_cut;
 
@@ -52,6 +52,7 @@ struct _ReverbBox {
   Data* data;
 };
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(ReverbBox, reverb_box, GTK_TYPE_BOX)
 
 void on_reset(ReverbBox* self, GtkButton* btn) {
@@ -59,45 +60,45 @@ void on_reset(ReverbBox* self, GtkButton* btn) {
 }
 
 void on_preset_room(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 0.445945);
-  gtk_spin_button_set_value(self->hf_damp, 5508.46);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(self->room_size), 4);
-  gtk_spin_button_set_value(self->diffusion, 0.54);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.469761));
-  gtk_spin_button_set_value(self->dry, util::linear_to_db(1.0));
-  gtk_spin_button_set_value(self->predelay, 25.0);
-  gtk_spin_button_set_value(self->bass_cut, 257.65);
-  gtk_spin_button_set_value(self->treble_cut, 20000.0);
+  g_settings_set_double(self->settings, "decay-time", 0.445945);
+  g_settings_set_double(self->settings, "hf-damp", 5508.46);
+  g_settings_set_enum(self->settings, "room-size", 4);
+  g_settings_set_double(self->settings, "diffusion", 0.54);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.469761));
+  g_settings_set_double(self->settings, "dry", util::linear_to_db(1.0));
+  g_settings_set_double(self->settings, "predelay", 25.0);
+  g_settings_set_double(self->settings, "bass-cut", 257.65);
+  g_settings_set_double(self->settings, "treble-cut", 20000.0);
 }
 
 void on_preset_empty_walls(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 0.505687);
-  gtk_spin_button_set_value(self->hf_damp, 3971.64);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(self->room_size), 4);
-  gtk_spin_button_set_value(self->diffusion, 0.17);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.198884));
-  gtk_spin_button_set_value(self->dry, util::linear_to_db(1.0));
-  gtk_spin_button_set_value(self->predelay, 13.0);
-  gtk_spin_button_set_value(self->bass_cut, 240.453);
-  gtk_spin_button_set_value(self->treble_cut, 3303.47);
+  g_settings_set_double(self->settings, "decay-time", 0.505687);
+  g_settings_set_double(self->settings, "hf-damp", 3971.64);
+  g_settings_set_enum(self->settings, "room-size", 4);
+  g_settings_set_double(self->settings, "diffusion", 0.17);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.198884));
+  g_settings_set_double(self->settings, "dry", util::linear_to_db(1.0));
+  g_settings_set_double(self->settings, "predelay", 13.0);
+  g_settings_set_double(self->settings, "bass-cut", 240.453);
+  g_settings_set_double(self->settings, "treble-cut", 3303.47);
 }
 
 void on_preset_ambience(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 1.10354);
-  gtk_spin_button_set_value(self->hf_damp, 2182.58);
-  gtk_combo_box_set_active(GTK_COMBO_BOX(self->room_size), 4);
-  gtk_spin_button_set_value(self->diffusion, 0.69);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.291183));
-  gtk_spin_button_set_value(self->dry, util::linear_to_db(1.0));
-  gtk_spin_button_set_value(self->predelay, 6.5);
-  gtk_spin_button_set_value(self->bass_cut, 514.079);
-  gtk_spin_button_set_value(self->treble_cut, 4064.15);
+  g_settings_set_double(self->settings, "decay-time", 1.10354);
+  g_settings_set_double(self->settings, "hf-damp", 2182.58);
+  g_settings_set_enum(self->settings, "room-size", 4);
+  g_settings_set_double(self->settings, "diffusion", 0.69);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.291183));
+  g_settings_set_double(self->settings, "dry", util::linear_to_db(1.0));
+  g_settings_set_double(self->settings, "predelay", 6.5);
+  g_settings_set_double(self->settings, "bass-cut", 514.079);
+  g_settings_set_double(self->settings, "treble-cut", 4064.15);
 }
 
 void on_preset_large_empty_hall(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 2.00689);
-  gtk_spin_button_set_value(self->hf_damp, 20000.0);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.366022));
+  g_settings_set_double(self->settings, "decay-time", 2.00689);
+  g_settings_set_double(self->settings, "hf-damp", 20000.0);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.366022));
   g_settings_reset(self->settings, "room-size");
   g_settings_reset(self->settings, "diffusion");
   g_settings_reset(self->settings, "dry");
@@ -107,9 +108,9 @@ void on_preset_large_empty_hall(ReverbBox* self, GtkButton* btn) {
 }
 
 void on_preset_disco(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 1.0);
-  gtk_spin_button_set_value(self->hf_damp, 3396.49);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.269807));
+  g_settings_set_double(self->settings, "decay-time", 1.0);
+  g_settings_set_double(self->settings, "hf-damp", 3396.49);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.269807));
   g_settings_reset(self->settings, "room-size");
   g_settings_reset(self->settings, "diffusion");
   g_settings_reset(self->settings, "dry");
@@ -119,9 +120,9 @@ void on_preset_disco(ReverbBox* self, GtkButton* btn) {
 }
 
 void on_preset_large_occupied_hall(ReverbBox* self, GtkButton* btn) {
-  gtk_spin_button_set_value(self->decay_time, 1.45397);
-  gtk_spin_button_set_value(self->hf_damp, 9795.58);
-  gtk_spin_button_set_value(self->wet, util::linear_to_db(0.184284));
+  g_settings_set_double(self->settings, "decay-time", 1.45397);
+  g_settings_set_double(self->settings, "hf-damp", 9795.58);
+  g_settings_set_double(self->settings, "amount", util::linear_to_db(0.184284));
   g_settings_reset(self->settings, "room-size");
   g_settings_reset(self->settings, "diffusion");
   g_settings_reset(self->settings, "dry");
@@ -192,7 +193,7 @@ void setup(ReverbBox* self, std::shared_ptr<Reverb> reverb, const std::string& s
   g_settings_bind(self->settings, "treble-cut", gtk_spin_button_get_adjustment(self->treble_cut), "value",
                   G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "room-size", self->room_size, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_dropdown(self->settings, "room-size", self->room_size);
 }
 
 void dispose(GObject* object) {
