@@ -73,6 +73,7 @@ struct _RNNoiseBox {
   Data* data;
 };
 
+// NOLINTNEXTLINE
 G_DEFINE_TYPE(RNNoiseBox, rnnoise_box, GTK_TYPE_BOX)
 
 void on_reset(RNNoiseBox* self, GtkButton* btn) {
@@ -80,8 +81,8 @@ void on_reset(RNNoiseBox* self, GtkButton* btn) {
 }
 
 void update_model_state(RNNoiseBox* self, const bool& load_error) {
-  gtk_widget_set_visible(GTK_WIDGET(self->model_error_state), load_error);
-  gtk_widget_set_visible(GTK_WIDGET(self->model_active_state), !load_error);
+  gtk_widget_set_visible(GTK_WIDGET(self->model_error_state), load_error ? 1 : 0);
+  gtk_widget_set_visible(GTK_WIDGET(self->model_active_state), !load_error ? 1 : 0);
 
   if (load_error) {
     ui::show_autohiding_toast(
@@ -127,35 +128,44 @@ void import_model_file(const std::string& file_path) {
 void on_import_model_clicked(RNNoiseBox* self, GtkButton* btn) {
   auto* active_window = gtk_application_get_active_window(GTK_APPLICATION(self->data->application));
 
-  auto* dialog = gtk_file_chooser_native_new(_("Import Model File"), active_window, GTK_FILE_CHOOSER_ACTION_OPEN,
-                                             _("Open"), _("Cancel"));
+  auto* dialog = gtk_file_dialog_new();
+
+  gtk_file_dialog_set_title(dialog, _("Import Model File"));
+  gtk_file_dialog_set_accept_label(dialog, _("Open"));
+
+  GListStore* filters = g_list_store_new(GTK_TYPE_FILE_FILTER);
 
   auto* filter = gtk_file_filter_new();
 
   gtk_file_filter_set_name(filter, _("RNNoise Models"));
   gtk_file_filter_add_pattern(filter, "*.rnnn");
 
-  gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
+  g_list_store_append(filters, filter);
 
-  g_signal_connect(dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, RNNoiseBox* self) {
-                     if (response == GTK_RESPONSE_ACCEPT) {
-                       auto* chooser = GTK_FILE_CHOOSER(dialog);
-                       auto* file = gtk_file_chooser_get_file(chooser);
-                       auto* path = g_file_get_path(file);
+  g_object_unref(filter);
 
-                       import_model_file(path);
+  gtk_file_dialog_set_filters(dialog, G_LIST_MODEL(filters));
 
-                       g_free(path);
+  g_object_unref(filters);
 
-                       g_object_unref(file);
-                     }
+  gtk_file_dialog_open(
+      dialog, active_window, nullptr,
+      +[](GObject* source_object, GAsyncResult* result, gpointer user_data) {
+        auto* dialog = GTK_FILE_DIALOG(source_object);
 
-                     g_object_unref(dialog);
-                   }),
-                   self);
+        auto* file = gtk_file_dialog_open_finish(dialog, result, nullptr);
 
-  gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(dialog), 1);
-  gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
+        if (file != nullptr) {
+          auto* path = g_file_get_path(file);
+
+          import_model_file(path);
+
+          g_free(path);
+
+          g_object_unref(file);
+        }
+      },
+      self);
 }
 
 void setup_listview(RNNoiseBox* self) {
@@ -231,7 +241,7 @@ void setup(RNNoiseBox* self,
   g_settings_bind_with_mapping(
       self->settings, "model-path", self->selection_model, "selected", G_SETTINGS_BIND_DEFAULT,
       +[](GValue* value, GVariant* variant, gpointer user_data) {
-        auto self = EE_RNNOISE_BOX(user_data);
+        auto* self = EE_RNNOISE_BOX(user_data);
 
         const auto* v = g_variant_get_string(variant, nullptr);
 
@@ -264,7 +274,7 @@ void setup(RNNoiseBox* self,
         return 1;
       },
       +[](const GValue* value, const GVariantType* expected_type, gpointer user_data) {
-        auto self = EE_RNNOISE_BOX(user_data);
+        auto* self = EE_RNNOISE_BOX(user_data);
 
         auto string_object =
             GTK_STRING_OBJECT(gtk_single_selection_get_selected_item(GTK_SINGLE_SELECTION(self->selection_model)));
